@@ -4,33 +4,19 @@
  */
 
 #pragma once
-#include <aws/kinesisvideo/KinesisVideo_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/kinesisvideo/KinesisVideo_EXPORTS.h>
 
-namespace Aws
-{
-namespace KinesisVideo
-{
-namespace Model
-{
-  enum class SyncStatus
-  {
-    NOT_SET,
-    SYNCING,
-    ACKNOWLEDGED,
-    IN_SYNC,
-    SYNC_FAILED,
-    DELETING,
-    DELETE_FAILED,
-    DELETING_ACKNOWLEDGED
-  };
+namespace Aws {
+namespace KinesisVideo {
+namespace Model {
+enum class SyncStatus { NOT_SET, SYNCING, ACKNOWLEDGED, IN_SYNC, SYNC_FAILED, DELETING, DELETE_FAILED, DELETING_ACKNOWLEDGED };
 
-namespace SyncStatusMapper
-{
+namespace SyncStatusMapper {
 AWS_KINESISVIDEO_API SyncStatus GetSyncStatusForName(const Aws::String& name);
 
 AWS_KINESISVIDEO_API Aws::String GetNameForSyncStatus(SyncStatus value);
-} // namespace SyncStatusMapper
-} // namespace Model
-} // namespace KinesisVideo
-} // namespace Aws
+}  // namespace SyncStatusMapper
+}  // namespace Model
+}  // namespace KinesisVideo
+}  // namespace Aws
